==> activity-custom-center-api-0.2.86-sources.jar: cn/com/duiba/activity/custom/center/api/dto/identity/IdentityCustomerRelationDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.identity;

import java.io.Serializable;
import java.util.Date;

/**
* 用户身份信息表
*/
public class IdentityCustomerRelationDto  implements Serializable {

    private static final long serialVersionUID = 8353590382633825809L;
    /**
    * 
    */
    private Long id;

    /**
    * 兑吧cid
    */
    private Long cid;

    /**
    * appId
    */
    private Long appId;

    /**
    * 关联内容
    */
    private String relContent;

    /**
    * 关联类型 1 手机号码
    */
    private Integer relType;

    /**
    * 兑吧uid
    */
    private String partnerid;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public Long getCid() {
        return cid;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setRelContent(String relContent) {
        this.relContent = relContent;
    }

    public String getRelContent() {
        return relContent;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }

    public Integer getRelType() {
        return relType;
    }

    public void setPartnerid(String partnerid) {
        this.partnerid = partnerid;
    }

    public String getPartnerid() {
        return partnerid;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> activity-custom-center-api-0.4.1-sources.jar: cn/com/duiba/activity/custom/center/api/dto/identity/IdentityCustomerRelationDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.identity;

import java.io.Serializable;
import java.util.Date;

/**
* 用户身份信息表
*/
public class IdentityCustomerRelationDto  implements Serializable {

    private static final long serialVersionUID = 8353590382633825809L;
    /**
    * 
    */
    private Long id;

    /**
    * 兑吧cid
    */
    private Long cid;

    /**
    * appId
    */
    private Long appId;

    /**
    * 关联内容
    */
    private String relContent;

    /**
    * 关联类型 1 手机号码
    */
    private Integer relType;

    /**
     * 扩展字段
     */
    private String extra;

    /**
    * 兑吧uid
    */
    private String partnerid;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public Long getCid() {
        return cid;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setRelContent(String relContent) {
        this.relContent = relContent;
    }

    public String getRelContent() {
        return relContent;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }

    public Integer getRelType() {
        return relType;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public void setPartnerid(String partnerid) {
        this.partnerid = partnerid;
    }

    public String getPartnerid() {
        return partnerid;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}
